Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(342)

Unified Diff: tests/html/isolates_test.dart

Issue 40323002: Remove dart:json (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Bad merge in convert/json.dart, a few other bugs. Updated co19 expectations. Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/corelib/string_source_test.dart ('k') | tests/lib/json/json_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/html/isolates_test.dart
diff --git a/tests/html/isolates_test.dart b/tests/html/isolates_test.dart
index 608593f93fa4ed2b3c7fdc8c4333b9ce886c0c02..1320d226dd0d1c14794be10871f54fd8a9f280a8 100644
--- a/tests/html/isolates_test.dart
+++ b/tests/html/isolates_test.dart
@@ -2,7 +2,7 @@ library IsolatesTest;
import '../../pkg/unittest/lib/unittest.dart';
import '../../pkg/unittest/lib/html_config.dart';
import 'dart:html';
-import 'dart:json';
+import 'dart:convert';
import 'dart:isolate' as isolate;
String responseFor(message) => 'response for $message';
@@ -19,8 +19,8 @@ void isolateEntry() {
return;
}
- // Check that JSON library was loaded to isolate.
- stringify([1, 2, 3]);
+ // Check that convert library was loaded to isolate.
+ JSON.encode([1, 2, 3]);
isolate.port.receive((message, replyTo) {
replyTo.send(responseFor(message), null);
« no previous file with comments | « tests/corelib/string_source_test.dart ('k') | tests/lib/json/json_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698